# Gramps Web API

This project provides a RESTful web API to query and manipulate a [Gramps](https://gramps-project.org) family tree database. It can serve e.g. as backend for a web app. Gramps Web API is the backend powering [Gramps Web](https://gramps-project.github.io/web/).

## API documentation

The documentation of the current state of the API can be browsed with Swagger:

[Gramps API docs](https://generator.swagger.io/?url=https://raw.githubusercontent.com/gramps-project/web-api/master/gramps_webapi/data/apispec.yaml)

The project is still under development, so API changes should be expected.

## Demo Server

A demo server is available at https://gramps-webapi-demo.herokuapp.com/api/metadata

## Documentation

The project's documentation is hosted at https://gramps-project.github.io/web/.
